# The `genreg` Package

This little package provides a class `Region`
that represents chromosomal genomic regions. Instances 
of the class can read and write themselves to and from
BED- and GFF-formatted files.

The `Region` class serves educational purposes only
and shall not be used in production code.